# Background
 > One investor might want to predict the trend for a specific stock, and to know which stock is better to invest in based on the past stock price. As stock market changing so rapidly, it might be hard to make the right investment strategy by analyzing the data manually. Thus, we built a tool for users to visualize, analyze, forecast and evaluate stocks.

# User Profile
 > Potential users could be individual (entry level) investors. For example 
students or young people, who put their spare money into the stock market
and is new for investment. They know their own investing strategy, and want
to know roughly how the price change in the near future. They can see the historical performance for the given stock such as the graph for price in the given time period. They can also see the predicted price and prediction interval for the following several days(for accuracy issue this time period can not be too large). In addition, if the input data set contains multiple stocks, they will see which one is the most valuable, i.e. increase the most.

# Data Sources
 > We use the stock data from yahoo finance API. In contains the open, close, high, low and adj close value for each stock on every stock market open day.

# Use cases
 > User case 1: Mike is a student in UW, he just gets a fellowship with 2000 dollars, and decides to put it into the stock market. However, he is a new investor and knowing nothing about the stock price. He wants to use this tool to get some historical information for the stocks he interested in, and also he wants to know whether these stocks will increase in the future. In addition, since he only have limited amount of money, he is curious about which stock should he buy.

 > User case 2: Jack a student in business school, he wants to do a project about how the stock price changed in the past ten years. It would be great if he can have some graph for the stock price, daily fluctuation and candle plot. Especially if he can put several stock price data into a same plot.
